( cd usr/lib ; rm -rf libatkmm-1.6.so )
( cd usr/lib ; ln -sf libatkmm-1.6.so.1.0.30 libatkmm-1.6.so )
( cd usr/lib ; rm -rf libgdkmm-2.4.so )
( cd usr/lib ; ln -sf libgdkmm-2.4.so.1.0.30 libgdkmm-2.4.so )
( cd usr/lib ; rm -rf libatkmm-1.6.so.1 )
( cd usr/lib ; ln -sf libatkmm-1.6.so.1.0.30 libatkmm-1.6.so.1 )
( cd usr/lib ; rm -rf libgtkmm-2.4.so.1 )
( cd usr/lib ; ln -sf libgtkmm-2.4.so.1.0.30 libgtkmm-2.4.so.1 )
( cd usr/lib ; rm -rf libgdkmm-2.4.so.1 )
( cd usr/lib ; ln -sf libgdkmm-2.4.so.1.0.30 libgdkmm-2.4.so.1 )
( cd usr/lib ; rm -rf libgtkmm-2.4.so )
( cd usr/lib ; ln -sf libgtkmm-2.4.so.1.0.30 libgtkmm-2.4.so )
